pub struct Verdict {
pub pass: bool,
pub reason: String,
}Expand description
What the judge decided. reason is recorded in the report so a surprising
verdict can be argued with rather than just believed.
Fields
pass: boolreason: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Verdict
impl<'de> Deserialize<'de> for Verdict
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more